@@ -1,8 +1,8 @@
 #Utility functions
 f.build <- function(y, rhs) {
-    if ((is.data.frame(rhs) || is.matrix(rhs)) && length(colnames(rhs)) > 0)
+    if ((is.data.frame(rhs) || is.matrix(rhs)) && is_not_null(colnames(rhs)))
         vars <- colnames(rhs)
-    else if (is.character(rhs) && length(rhs) > 0)
+    else if (is.character(rhs) && is_not_null(rhs))
         vars <- rhs
     else stop("Right hand side argument to f.build() must be a vector of variable names or a data set with named variables.", call. = FALSE)
     if (!(is.character(y) && length(y) == 1)) stop ("Response argument to f.build() must be the quoted name of the response variable.", call. = FALSE)
@@ -41,7 +41,7 @@ splitfactor <- function(data, var.name, replace = TRUE, sep = "_", drop.level =
             else {
                 stop("var.name must be a character vector of the name(s) of factor variable(s) in data.", call. = FALSE)
             }
-            if (length(factor.names) == 0) {
+            if (is_null(factor.names)) {
                 stop("There are no factor variables to split in data.", call. = FALSE)
             }
         }
@@ -73,7 +73,7 @@ splitfactor <- function(data, var.name, replace = TRUE, sep = "_", drop.level =
             names(data) <- dep
         }
         else if (is.vector(var.name) && (is.atomic(var.name) || is.factor(var.name))) {
-            if (length(var.name) == 0) {
+            if (is_null(var.name)) {
                 names(data) <- dep
             }
             else if (length(var.name) == 1) {
@@ -93,7 +93,7 @@ splitfactor <- function(data, var.name, replace = TRUE, sep = "_", drop.level =
         stop("data must a be a data.frame or an atomic vector.", call. = FALSE)
     }
     
-    if (length(drop.level) > 0 && length(var.name) > 1) {
+    if (is_not_null(drop.level) && length(var.name) > 1) {
         warning("drop.level cannot be used with multiple entries to var.name. Ignoring drop.level.", call. = FALSE)
         drop.level <- NULL
     }
@@ -132,7 +132,7 @@ splitfactor <- function(data, var.name, replace = TRUE, sep = "_", drop.level =
         if (!skip) {
             colnames(k) <- paste(v, sapply(strsplit(colnames(k), v, fixed = TRUE), function(n) paste(n, collapse = "")), sep = sep)
             
-            if (length(drop.level) > 0) {
+            if (is_not_null(drop.level)) {
                 if (is.character(drop.level) && length(drop.level) == 1 && drop.level %in% levels(x)) {
                     drop <- drop.level
                 }
@@ -148,7 +148,7 @@ splitfactor <- function(data, var.name, replace = TRUE, sep = "_", drop.level =
             }
             
             dropl <- rep(FALSE, ncol(k))
-            if (length(drop) > 0) {
+            if (is_not_null(drop)) {
                 dropl[!is.na(levels(x)) & levels(x) %in% drop] <- TRUE
             }
             if (drop.na[v]) dropl[is.na(levels(x))] <- TRUE
@@ -183,7 +183,7 @@ unsplitfactor <- function(data, var.name, replace = TRUE, sep = "_", dropped.lev
     
     if (!is.data.frame(data)) stop("data must be a data.frame containing the variables to unsplit.", call = FALSE)
     if (!is.character(var.name)) stop("var.name must be a string containing the name of the variables to unsplit.", call. = FALSE)
-    if (length(dropped.level) > 0 && length(var.name) > 1) {
+    if (is_not_null(dropped.level) && length(var.name) > 1) {
         warning("dropped.level cannot be used with multiple var.names and will be ignored.", call. = FALSE, immediate. = TRUE)
         dropped.level <- NULL
     }
@@ -199,7 +199,7 @@ unsplitfactor <- function(data, var.name, replace = TRUE, sep = "_", dropped.lev
     for (v in var.name) {
         dropped.level0 <- dropped.level
         var.to.combine <- data[startsWith(names(data), paste0(v, sep))]
-        if (length(var.to.combine) == 0) {
+        if (is_null(var.to.combine)) {
             not.the.stem <- c(not.the.stem, paste0(v, sep))
             next
         }
@@ -226,7 +226,7 @@ unsplitfactor <- function(data, var.name, replace = TRUE, sep = "_", dropped.lev
         else if (isTRUE(all.equal(sort(unique(var.sum)), c(0, 1)))) {
             #Missing category
             
-            if (length(dropped.level) == 0) {
+            if (is_null(dropped.level)) {
                 k.levels0 <- sapply(names(var.to.combine), function(x) strsplit(x, paste0(v, sep))[[1]][2])
                 
                 if (suppressWarnings(all(!is.na(as.numeric(k.levels0))))) {
@@ -263,7 +263,7 @@ unsplitfactor <- function(data, var.name, replace = TRUE, sep = "_", dropped.lev
             
             data[[min(where)]] <- k
             remove.cols <- where[where!=min(where)]
-            if (length(remove.cols) > 0) data <- data[-remove.cols]
+            if (is_not_null(remove.cols)) data <- data[-remove.cols]
             names(data)[min(where)] <- v
         }
         else {
@@ -271,7 +271,7 @@ unsplitfactor <- function(data, var.name, replace = TRUE, sep = "_", dropped.lev
         }
     }
     
-    if (length(not.the.stem) > 0) warning(paste0(word.list(not.the.stem, is.are = TRUE, quotes = TRUE), " not the stem of any variables in data and will be ignored. Ensure var.name and sep are correct."), call. = FALSE)
+    if (is_not_null(not.the.stem)) warning(paste0(word.list(not.the.stem, is.are = TRUE, quotes = TRUE), " not the stem of any variables in data and will be ignored. Ensure var.name and sep are correct."), call. = FALSE)
     
     return(data)
 }
@@ -282,10 +282,10 @@ get.w.matchit <- function(m,...) {
 }
 get.w.ps <- function(ps, stop.method = NULL, estimand = NULL, s.weights = FALSE, ...) {
     estimand <- tolower(estimand)
-    if (length(stop.method) > 0) {
+    if (is_not_null(stop.method)) {
         if (any(is.character(stop.method))) {
             rule1 <- names(ps$w)[sapply(names(ps$w), function(x) any(startsWith(tolower(x), tolower(stop.method))))]
-            if (length(rule1) == 0) {
+            if (is_null(rule1)) {
                 message(paste0("Warning: stop.method should be ", word.list(names(ps$w), and.or = "or", quotes = TRUE), ".\nUsing all available stop methods instead."))
                 rule1 <- names(ps$w)
             }
@@ -311,7 +311,7 @@ get.w.ps <- function(ps, stop.method = NULL, estimand = NULL, s.weights = FALSE,
     
     s <- names(ps$w)[match(tolower(rule1), tolower(names(ps$w)))]
     
-    if (length(estimand) == 0) estimand <- setNames(substr(tolower(s), nchar(s)-2, nchar(s)), s)
+    if (is_null(estimand)) estimand <- setNames(substr(tolower(s), nchar(s)-2, nchar(s)), s)
     else if (!all(tolower(estimand) %in% c("att", "ate", "atc"))) {
         stop('estimand must be "ATT", "ATE", or "ATC".', call. = FALSE)
     }
@@ -319,27 +319,25 @@ get.w.ps <- function(ps, stop.method = NULL, estimand = NULL, s.weights = FALSE,
         names(estimand) <- s
     }
     
-    w <- setNames(lapply(seq_along(s), function(p) {
-        if (estimand[p] == "att") ps$treat + (1-ps$treat)*ps$ps[,s[p]]/(1-ps$ps[,s[p]])
-        else if (estimand[p] == "ate") ps$treat/ps$ps[,s[p]] + (1-ps$treat)/(1-ps$ps[,s[p]])
-        else if (estimand[p] == "atc") (1-ps$treat) + ps$treat*ps$ps[,s[p]]/(1-ps$ps[,s[p]])}),
-        ifelse(tolower(substr(s, nchar(s)-2, nchar(s))) == tolower(estimand), s, paste0(s, " (", toupper(estimand), ")")))
-    
-    if (s.weights) {
-        w <- w * ps$sampw
+    w <- setNames(as.data.frame(matrix(1, nrow = nrow(ps$ps), ncol = length(s))),
+                  ifelse(tolower(substr(s, nchar(s)-2, nchar(s))) == tolower(estimand), s, paste0(s, " (", toupper(estimand), ")")))
+    for (p in s) {
+        if (estimand[p] == "att") w[[p]] <- ps$treat + (1-ps$treat)*ps$ps[,p]/(1-ps$ps[,p])
+        else if (estimand[p] == "ate") w[[p]] <- ps$treat/ps$ps[,p] + (1-ps$treat)/(1-ps$ps[,p])
+        else if (estimand[p] == "atc") w[[p]] <- (1-ps$treat) + ps$treat*ps$ps[,p]/(1-ps$ps[,p])
+        else w[[p]] <- ps$w[,p]
+        if (s.weights) w[[p]] <- w[[p]] * ps$sampw
     }
     
-    if (length(w) == 1) w <- w[[1]]
-    else {
-        class(w) <- "data.frame"; attr(w, "row.names") <- .set_row_names(length(w[[1]]))
-    }
+    if (ncol(w) == 1) w <- w[[1]]
+
     return(w)
 }
 get.w.mnps <- function(mnps, stop.method = NULL, s.weights = FALSE, ...) {
-    if (length(stop.method) > 0) {
+    if (is_not_null(stop.method)) {
         if (any(is.character(stop.method))) {
             rule1 <- mnps$stopMethods[sapply(t(sapply(tolower(stop.method), function(x) startsWith(tolower(mnps$stopMethods), x))), any)]
-            if (length(rule1) == 0) {
+            if (is_null(rule1)) {
                 message(paste0("Warning: stop.method should be ", word.list(mnps$stopMethods, and.or = "or", quotes = TRUE), ".\nUsing all available stop methods instead."))
                 rule1 <- mnps$stopMethods
             }
@@ -397,11 +395,53 @@ get.w.mnps <- function(mnps, stop.method = NULL, s.weights = FALSE, ...) {
     
     return(w)
 }
+get.w.ps.cont <- function(ps.cont, stop.method = NULL, s.weights = FALSE, ...) {
+    if (is_not_null(stop.method)) {
+        if (any(is.character(stop.method))) {
+            rule1 <- names(ps.cont$w)[sapply(names(ps.cont$w), function(x) any(startsWith(tolower(x), tolower(stop.method))))]
+            if (is_null(rule1)) {
+                message(paste0("Warning: stop.method should be ", word.list(names(ps.cont$w), and.or = "or", quotes = TRUE), ".\nUsing all available stop methods instead."))
+                rule1 <- names(ps.cont$w)
+            }
+            # rule1 <- tryCatch(match.arg(tolower(stop.method), tolower(names(ps$w)), several.ok = TRUE),
+            #                   error = function(cond) {message(paste0("Warning: stop.method should be ", word.list(names(ps$w), and.or = "or", quotes = TRUE), ".\nUsing all available stop methods instead."));
+            #                       return(names(ps$w))})
+        }
+        else if (is.numeric(stop.method) && any(stop.method %in% seq_along(names(ps.cont$w)))) {
+            if (any(!stop.method %in% seq_along(names(ps.cont$w)))) {
+                message(paste0("Warning: There are ", length(names(ps.cont$w)), " stop methods available, but you requested ", 
+                               word.list(stop.method[!stop.method %in% seq_along(names(ps.cont$w))], and.or = "and"),"."))
+            }
+            rule1 <- names(ps.cont$w)[stop.method %in% seq_along(names(ps.cont$w))]
+        }
+        else {
+            warning("stop.method should be ", word.list(names(ps.cont$w), and.or = "or", quotes = TRUE), ".\nUsing all available stop methods instead.", call. = FALSE)
+            rule1 <- names(ps.cont$w)
+        }
+    }
+    else {
+        rule1 <- names(ps.cont$w)
+    }
+    
+    s <- names(ps.cont$w)[match(tolower(rule1), tolower(names(ps.cont$w)))]
+    
+    w <- setNames(as.data.frame(matrix(1, nrow = nrow(ps.cont$w), ncol = length(s))),
+                  s)
+    
+    for (p in s) {
+        w[[p]] <- ps.cont$w[[p]]
+        if (!s.weights && is_not_null(ps.cont$sampw)) w[[p]] <- w[[p]] / ps.cont$sampw
+    }
+
+    if (ncol(w) == 1) w <- w[[1]]
+
+    return(w)
+}
 get.w.iptw <- function(iptw, stop.method = NULL, s.weights = FALSE, ...) {
-    if (length(stop.method) > 0) {
+    if (is_not_null(stop.method)) {
         if (any(is.character(stop.method))) {
             rule1 <- names(iptw$psList[[1]]$ps)[sapply(names(iptw$psList[[1]]$ps), function(x) any(startsWith(tolower(x), tolower(stop.method))))]
-            if (length(rule1) == 0) {
+            if (is_null(rule1)) {
                 message(paste0("Warning: stop.method should be ", word.list(names(iptw$psList[[1]]$ps), and.or = "or", quotes = TRUE), ".\nUsing all available stop methods instead."))
                 rule1 <- names(iptw$psList[[1]]$ps)
             }
@@ -457,7 +497,7 @@ get.w.Match <- function(M,  ...) {
 }
 get.w.CBPS <- function(c, estimand = NULL, ...) {
     A <- list(...)
-    if (length(A$use.weights) == 0) use.weights <- TRUE
+    if (is_null(A$use.weights)) use.weights <- TRUE
     else use.weights <- A$use.weights
     
     estimand <- tolower(estimand)
@@ -469,13 +509,11 @@ get.w.CBPS <- function(c, estimand = NULL, ...) {
         if (!use.weights) {
             ps <- c$fitted.values
             t <- c$y 
-            if (length(estimand) == 0) {
-                if (abs(max(c$weights[t == 1], na.rm = TRUE) - 
-                        min(c$weights[t == 1], na.rm = TRUE)) < 
-                    sqrt(.Machine$double.eps)) {
-                    estimand <- "att"
+            if (is_null(estimand)) {
+                if (nunique.gt(c$weights[t == 1], 1)) {
+                    estimand <- "ate"
                 }
-                else estimand <- "ate"
+                else estimand <- "att"
             }
             
             estimand <- match.arg(tolower(estimand), c("att", "atc", "ate"))
@@ -495,7 +533,7 @@ get.w.CBPS <- function(c, estimand = NULL, ...) {
         
     }
 }
-get.w.npCBPS <- function(c, estimand = NULL, ...) {
+get.w.npCBPS <- function(c, ...) {
     return(c$weights)
 }
 get.w.CBMSM <- function(c, ...) {
@@ -505,7 +543,7 @@ get.w.ebalance <- function(e, treat, ...) {
     if (missing(treat)) stop("treat must be specified.", call. = FALSE)
     
     weights <- rep(1, length(treat))
-
+    
     if (length(e$w) != sum(treat == 0)) {
         stop("There are more control units in treat than weights in the ebalance object.", call. = FALSE)
     }
@@ -521,6 +559,26 @@ get.w.weightit <- function(W, s.weights = FALSE, ...) {
     if (s.weights) return(W$weights * W$s.weights)
     else return(W$weights)
 }
+get.w.designmatch <- function(dm, treat, ...) {
+    if (missing(treat)) stop("treat must be specified.", call. = FALSE)
+    if (length(dm[["group_id"]]) != length(dm[["t_id"]]) + length(dm[["c_id"]])) {
+        ratio <- length(dm[["c_id"]])/length(dm[["t_id"]])
+        if (check_if_zero(ratio - as.integer(ratio))) {
+            dm[["group_id"]] <- c(seq_along(dm[["t_id"]]),
+                                  rep(seq_along(dm[["c_id"]]), each = as.integer(ratio)))
+        }
+        else {
+            stop("There is a problem with the group_id value in the designmatch output. Matched sets cannot be determined.", call. = FALSE)
+        }
+    }
+    q <- merge(data.frame(id = seq_along(treat)), 
+               data.frame(id = c(dm[["t_id"]], dm[["c_id"]]),
+                          group = dm[["group_id"]]),
+               all.x = TRUE, by = "id")
+    q <- q[order(q$id), , drop = FALSE]
+    
+    return(match.strata2weights(q$group, treat))
+}
 
 #For cobalt
 word.list <- function(word.list = NULL, and.or = c("and", "or"), is.are = FALSE, quotes = FALSE) {
@@ -567,7 +625,7 @@ expand.grid_string <- function(..., collapse = "") {
     return(apply(expand.grid(...), 1, paste, collapse = collapse))
 }
 nunique <- function(x, nmax = NA, na.rm = TRUE) {
-    if (length(x) == 0) return(0)
+    if (is_null(x)) return(0)
     else {
         if (na.rm) x <- x[!is.na(x)]
         if (is.factor(x)) return(nlevels(x))
@@ -576,14 +634,18 @@ nunique <- function(x, nmax = NA, na.rm = TRUE) {
     
 }
 nunique.gt <- function(x, n, na.rm = TRUE) {
-    if (n < 0) stop("n must be non-negative.", call. = FALSE)
-    if (length(x) == 0) FALSE
+    if (missing(n)) stop("n must be supplied.")
+    if (n < 0) stop("n must be non-negative.")
+    if (is_null(x)) FALSE
     else {
         if (na.rm) x <- x[!is.na(x)]
-        if (length(x) < 2000) nunique(x) > n
-        else tryCatch(nunique(x, nmax = n) > n, error = function(e) TRUE)        
+        if (n == 1 && is.numeric(x)) !check_if_zero(max(x) - min(x))
+        else if (length(x) < 2000) nunique(x) > n
+        else tryCatch(nunique(x, nmax = n) > n, error = function(e) TRUE)
     }
 }
+is_binary <- function(x) !nunique.gt(x, 2)
+all_the_same <- function(x) !nunique.gt(x, 1)
 is.formula <- function(f, sides = NULL) {
     res <- is.name(f[[1]])  && deparse(f[[1]]) %in% c( '~', '!') &&
         length(f) >= 2
@@ -591,4 +653,22 @@ is.formula <- function(f, sides = NULL) {
         res <- res && length(f) == sides + 1
     }
     return(res)
+}
+check_if_zero_base <- function(x) {
+    # this is the default tolerance used in all.equal
+    tolerance <- .Machine$double.eps^0.5
+    # If the absolute deviation between the number and zero is less than
+    # the tolerance of the floating point arithmetic, then return TRUE.
+    # This means, to me, that I can treat the number as 0 rather than
+    # -3.20469e-16 or some such.
+    abs(x - 0) < tolerance
+}
+check_if_zero <- Vectorize(check_if_zero_base)
+is_null <- function(x) length(x) == 0L
+is_not_null <- function(x) !is_null(x)
+`%nin%` <- function(x, table) is.na(match(x, table, nomatch = NA_integer_))
+`%+%` <- function(...) {
+    a <- list(...)
+    if (is.character(a[[1]])) do.call(crayon::`%+%`, a)
+    else do.call(ggplot2::`%+%`, a)
 }
\ No newline at end of file
